<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="zh_HK">
<context>
    <name>Application</name>
    <message>
        <location filename="../reader/Application.cpp" line="39"/>
        <source>Document Viewer</source>
        <translation>文檔查看器</translation>
    </message>
    <message>
        <location filename="../reader/Application.cpp" line="40"/>
        <source>Document Viewer is a tool for reading document files, supporting PDF, DJVU, DOCX etc.</source>
        <translation>文檔查看器是一款支持PDF、DJVU、DOCX等多種格式的文檔閱讀工具。</translation>
    </message>
</context>
<context>
    <name>AttrScrollWidget</name>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="46"/>
        <source>Location</source>
        <translation>位置</translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="47"/>
        <source>Subject</source>
        <translation>主題</translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="48"/>
        <source>Author</source>
        <translation>作者</translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="49"/>
        <source>Keywords</source>
        <translation>關鍵詞</translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="50"/>
        <source>Producer</source>
        <translation>製作者</translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="51"/>
        <source>Creator</source>
        <translation>創建者</translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="52"/>
        <source>Time created</source>
        <translation>創建於</translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="53"/>
        <source>Time modified</source>
        <translation>修改於</translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="54"/>
        <source>Format</source>
        <translation>格式</translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="55"/>
        <source>Pages</source>
        <translation>頁數</translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="56"/>
        <source>Optimized</source>
        <translation>優化</translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="57"/>
        <source>Security</source>
        <translation>安全性</translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="59"/>
        <source>Page size</source>
        <translation>頁面大小</translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="60"/>
        <source>File size</source>
        <translation>文件大小</translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="65"/>
        <source>Basic info</source>
        <translation>基本訊息</translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="85"/>
        <source>Unknown</source>
        <translation>未知</translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="127"/>
        <source>Yes</source>
        <translation>是</translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="127"/>
        <source>No</source>
        <translation>否</translation>
    </message>
</context>
<context>
    <name>BookMarkWidget</name>
    <message>
        <location filename="../reader/sidebar/BookMarkWidget.cpp" line="64"/>
        <source>Add bookmark</source>
        <translation>添加書籤</translation>
    </message>
    <message>
        <location filename="../reader/sidebar/BookMarkWidget.cpp" line="220"/>
        <source>Are you sure you want to delete all bookmarks?</source>
        <translation>您確定要刪除所有書籤嗎？</translation>
    </message>
</context>
<context>
    <name>BrowserMenu</name>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="39"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="52"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="56"/>
        <source>Copy</source>
        <translation>複製</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="43"/>
        <source>Remove annotation</source>
        <translation>刪除注釋</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="44"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="73"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="134"/>
        <source>Add annotation</source>
        <translation>添加注釋</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="47"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="77"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="85"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="129"/>
        <source>Remove bookmark</source>
        <translation>刪除書籤</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="49"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="79"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="87"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="131"/>
        <source>Add bookmark</source>
        <translation>添加書籤</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="60"/>
        <source>Highlight</source>
        <translation>高亮</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="69"/>
        <source>Remove highlight</source>
        <translation>取消高亮</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="81"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="124"/>
        <source>Search</source>
        <translation>搜索</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="92"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="140"/>
        <source>Exit fullscreen</source>
        <translation>退出全屏</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="94"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="142"/>
        <source>Fullscreen</source>
        <translation>全屏</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="97"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="145"/>
        <source>Slide show</source>
        <translation>幻燈片放映</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="100"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="148"/>
        <source>First page</source>
        <translation>第一頁</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="101"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="149"/>
        <source>Previous page</source>
        <translation>前一頁</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="107"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="155"/>
        <source>Next page</source>
        <translation>後一頁</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="108"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="156"/>
        <source>Last page</source>
        <translation>最後一頁</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="116"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="164"/>
        <source>Rotate left</source>
        <translation>左旋轉</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="117"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="165"/>
        <source>Rotate right</source>
        <translation>右旋轉</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="120"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="168"/>
        <source>Print</source>
        <translation>打印</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="121"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="169"/>
        <source>Document info</source>
        <translation>文檔訊息</translation>
    </message>
</context>
<context>
    <name>Central</name>
    <message>
        <location filename="../reader/uiframe/Central.cpp" line="145"/>
        <source>Documents</source>
        <translation>文檔文件</translation>
    </message>
</context>
<context>
    <name>CentralDocPage</name>
    <message>
        <location filename="../reader/uiframe/CentralDocPage.cpp" line="166"/>
        <source>The format is not supported</source>
        <translation>不支持該文件格式</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/CentralDocPage.cpp" line="208"/>
        <source>Open failed</source>
        <translation>打開失敗</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/CentralDocPage.cpp" line="210"/>
        <source>Please check if the file is damaged</source>
        <translation>請檢查文件是否損壞</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/CentralDocPage.cpp" line="212"/>
        <source>Conversion failed, please check if the file is damaged</source>
        <translation>轉換失敗，請檢查文件是否損壞</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/CentralDocPage.cpp" line="420"/>
        <source>Save failed</source>
        <translation>保存失敗</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/CentralDocPage.cpp" line="426"/>
        <source>Saved successfully</source>
        <translation>保存成功</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/CentralDocPage.cpp" line="444"/>
        <source>Save as</source>
        <translation>另存為</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/CentralDocPage.cpp" line="453"/>
        <location filename="../reader/uiframe/CentralDocPage.cpp" line="463"/>
        <source>Invalid file name</source>
        <translation>請輸入有效的文件名</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/CentralDocPage.cpp" line="455"/>
        <location filename="../reader/uiframe/CentralDocPage.cpp" line="465"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>確 定</translation>
    </message>
</context>
<context>
    <name>CentralNavPage</name>
    <message>
        <location filename="../reader/uiframe/CentralNavPage.cpp" line="35"/>
        <source>Drag documents here</source>
        <translation>拖拽文件到此</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/CentralNavPage.cpp" line="41"/>
        <source>Format supported: %1</source>
        <translation>支持格式：%1 </translation>
    </message>
    <message>
        <location filename="../reader/uiframe/CentralNavPage.cpp" line="47"/>
        <source>Select File</source>
        <translation>選擇文件</translation>
    </message>
</context>
<context>
    <name>DocSheet</name>
    <message>
        <location filename="../reader/uiframe/DocSheet.cpp" line="327"/>
        <location filename="../reader/uiframe/DocSheet.cpp" line="355"/>
        <source>The bookmark has been removed</source>
        <translation>已刪除書籤</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/DocSheet.cpp" line="528"/>
        <location filename="../reader/uiframe/DocSheet.cpp" line="543"/>
        <source>Please select the text</source>
        <translation>請選擇文本</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/DocSheet.cpp" line="593"/>
        <location filename="../reader/uiframe/DocSheet.cpp" line="602"/>
        <source>The annotation has been removed</source>
        <translation>已刪除注釋</translation>
    </message>
</context>
<context>
    <name>EncryptionPage</name>
    <message>
        <location filename="../reader/widgets/EncryptionPage.cpp" line="50"/>
        <source>Encrypted file, please enter the password</source>
        <translation>此文檔已加密，請輸入密碼</translation>
    </message>
    <message>
        <location filename="../reader/widgets/EncryptionPage.cpp" line="56"/>
        <source>Password</source>
        <translation>密碼</translation>
    </message>
    <message>
        <location filename="../reader/widgets/EncryptionPage.cpp" line="61"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>確 定</translation>
    </message>
    <message>
        <location filename="../reader/widgets/EncryptionPage.cpp" line="105"/>
        <source>Wrong password</source>
        <translation>密碼錯誤</translation>
    </message>
</context>
<context>
    <name>FindWidget</name>
    <message>
        <location filename="../reader/widgets/FindWidget.cpp" line="125"/>
        <source>Previous</source>
        <translation>上一個</translation>
    </message>
    <message>
        <location filename="../reader/widgets/FindWidget.cpp" line="133"/>
        <source>Next</source>
        <translation>下一個</translation>
    </message>
</context>
<context>
    <name>HandleMenu</name>
    <message>
        <location filename="../reader/widgets/HandleMenu.cpp" line="35"/>
        <source>Select Text</source>
        <translation>選擇工具</translation>
    </message>
    <message>
        <location filename="../reader/widgets/HandleMenu.cpp" line="43"/>
        <source>Hand Tool</source>
        <translation>手形工具</translation>
    </message>
</context>
<context>
    <name>NotesWidget</name>
    <message>
        <location filename="../reader/sidebar/NotesWidget.cpp" line="67"/>
        <source>Add annotation</source>
        <translation>添加注釋</translation>
    </message>
    <message>
        <location filename="../reader/sidebar/NotesWidget.cpp" line="189"/>
        <source>Are you sure you want to delete all annotations?</source>
        <translation>您確定要刪除所有注釋嗎？</translation>
    </message>
</context>
<context>
    <name>PagingWidget</name>
    <message>
        <location filename="../reader/widgets/PagingWidget.cpp" line="212"/>
        <source>Invalid page number</source>
        <translation>請輸入有效的頁碼</translation>
    </message>
</context>
<context>
    <name>ProgressDialog</name>
    <message>
        <location filename="../reader/widgets/ProgressDialog.cpp" line="18"/>
        <source>Converting</source>
        <translation>正在轉換</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../reader/app/DBusObject.cpp" line="103"/>
        <source>Document not saved</source>
        <translation>文檔未保存</translation>
    </message>
</context>
<context>
    <name>SaveDialog</name>
    <message>
        <location filename="../reader/widgets/SaveDialog.cpp" line="35"/>
        <source>Save the changes to &quot;%1&quot;?</source>
        <translation>是否保存對“%1”的編輯？</translation>
    </message>
    <message>
        <location filename="../reader/widgets/SaveDialog.cpp" line="37"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>取 消</translation>
    </message>
    <message>
        <location filename="../reader/widgets/SaveDialog.cpp" line="37"/>
        <source>Discard</source>
        <comment>button</comment>
        <translation>不保存</translation>
    </message>
    <message>
        <location filename="../reader/widgets/SaveDialog.cpp" line="38"/>
        <source>Save</source>
        <comment>button</comment>
        <translation>保 存</translation>
    </message>
    <message>
        <location filename="../reader/widgets/SaveDialog.cpp" line="49"/>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <location filename="../reader/widgets/SaveDialog.cpp" line="50"/>
        <source>Delete</source>
        <translation>刪除</translation>
    </message>
</context>
<context>
    <name>ScaleMenu</name>
    <message>
        <location filename="../reader/widgets/ScaleMenu.cpp" line="35"/>
        <source>Two-Page View</source>
        <translation>雙頁顯示</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ScaleMenu.cpp" line="36"/>
        <source>1:1 size</source>
        <translation>默認大小</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ScaleMenu.cpp" line="37"/>
        <source>Fit Page</source>
        <translation>適合頁面</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ScaleMenu.cpp" line="38"/>
        <source>Fit Height</source>
        <translation>適應高度</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ScaleMenu.cpp" line="39"/>
        <source>Fit Width</source>
        <translation>適應寬度</translation>
    </message>
</context>
<context>
    <name>SearchResWidget</name>
    <message>
        <location filename="../reader/sidebar/SearchResWidget.cpp" line="60"/>
        <source>No search results</source>
        <translation>無搜索結果</translation>
    </message>
    <message>
        <location filename="../reader/sidebar/SearchResWidget.cpp" line="109"/>
        <source>%1 items found</source>
        <translation>%1個搜索結果</translation>
    </message>
</context>
<context>
    <name>SecurityDialog</name>
    <message>
        <location filename="../reader/widgets/SecurityDialog.cpp" line="72"/>
        <source>This document is trying to connect to:</source>
        <translation>文檔正在嘗試鏈接至：</translation>
    </message>
    <message>
        <location filename="../reader/widgets/SecurityDialog.cpp" line="73"/>
        <source>If you trust the website, click Allow, otherwise click Block.</source>
        <translation>如果信任該網站，請點擊“允許”，否則請選擇“阻止”。</translation>
    </message>
    <message>
        <location filename="../reader/widgets/SecurityDialog.cpp" line="76"/>
        <source>Block</source>
        <comment>button</comment>
        <translation>阻止</translation>
    </message>
    <message>
        <location filename="../reader/widgets/SecurityDialog.cpp" line="77"/>
        <source>Allow</source>
        <comment>button</comment>
        <translation>允許</translation>
    </message>
</context>
<context>
    <name>SheetSidebar</name>
    <message>
        <location filename="../reader/sidebar/SheetSidebar.cpp" line="84"/>
        <source>Thumbnails</source>
        <translation>打開目錄縮略圖</translation>
    </message>
    <message>
        <location filename="../reader/sidebar/SheetSidebar.cpp" line="99"/>
        <source>Catalog</source>
        <translation>目錄</translation>
    </message>
    <message>
        <location filename="../reader/sidebar/SheetSidebar.cpp" line="112"/>
        <source>Bookmarks</source>
        <translation>書籤</translation>
    </message>
    <message>
        <location filename="../reader/sidebar/SheetSidebar.cpp" line="127"/>
        <source>Annotations</source>
        <translation>注釋</translation>
    </message>
</context>
<context>
    <name>ShortCutShow</name>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="58"/>
        <source>Settings</source>
        <translation>設置</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="79"/>
        <source>Files</source>
        <translation>文件</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="100"/>
        <source>Display</source>
        <translation>視圖</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="120"/>
        <source>Tools</source>
        <translation>工具</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="142"/>
        <source>Edit</source>
        <translation>編輯</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="193"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="203"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="234"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="245"/>
        <source>Exit</source>
        <translation>退出</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="193"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="200"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="234"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="242"/>
        <source>Help</source>
        <translation>幫助</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="193"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="203"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="234"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="245"/>
        <source>Page up</source>
        <translation>上一頁</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="193"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="203"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="234"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="245"/>
        <source>Page down</source>
        <translation>下一頁</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="193"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="201"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="235"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="243"/>
        <source>Open</source>
        <translation>打開</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="194"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="203"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="235"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="245"/>
        <source>Zoom in</source>
        <translation>頁面放大</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="194"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="203"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="235"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="245"/>
        <source>Zoom out</source>
        <translation>頁面縮小</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="194"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="235"/>
        <source>Zoom in/Zoom out</source>
        <translation>頁面放大/縮小</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="194"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="201"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="235"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="243"/>
        <source>Save as</source>
        <translation>另存為</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="194"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="201"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="236"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="243"/>
        <source>Print</source>
        <translation>打印</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="195"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="201"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="206"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="236"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="243"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="248"/>
        <source>Save</source>
        <translation>保存</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="195"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="202"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="236"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="244"/>
        <source>Thumbnails</source>
        <translation>打開目錄縮略圖</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="195"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="202"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="236"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="244"/>
        <source>1:1 size</source>
        <translation>默認大小</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="195"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="202"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="236"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="244"/>
        <source>Fit height</source>
        <translation>適合高度</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="195"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="202"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="237"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="244"/>
        <source>Fit width</source>
        <translation>適合寬度</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="196"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="202"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="237"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="244"/>
        <source>Rotate left</source>
        <translation>左旋轉</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="196"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="202"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="237"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="244"/>
        <source>Rotate right</source>
        <translation>右旋轉</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="196"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="204"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="237"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="246"/>
        <source>Select text</source>
        <translation>選擇工具</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="196"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="204"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="237"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="246"/>
        <source>Hand tool</source>
        <translation>手形工具</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="196"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="204"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="238"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="246"/>
        <source>Add bookmark</source>
        <translation>添加書籤</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="197"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="204"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="206"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="238"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="246"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="248"/>
        <source>Delete</source>
        <translation>刪除</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="197"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="205"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="238"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="247"/>
        <source>Magnifier</source>
        <translation>放大鏡</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="197"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="205"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="239"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="247"/>
        <source>Slide show</source>
        <translation>幻燈片放映</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="197"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="205"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="239"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="247"/>
        <source>Fullscreen</source>
        <translation>全屏</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="197"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="206"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="239"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="248"/>
        <source>Copy</source>
        <translation>複製</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="198"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="206"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="239"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="248"/>
        <source>Cut</source>
        <translation>剪切</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="198"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="206"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="239"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="248"/>
        <source>Paste</source>
        <translation>黏貼</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="198"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="206"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="240"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="248"/>
        <source>Undo</source>
        <translation>撤銷</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="198"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="206"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="240"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="248"/>
        <source>Select all</source>
        <translation>全選</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="198"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="200"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="240"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="242"/>
        <source>Display shortcuts</source>
        <translation>顯示快捷鍵</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="204"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="238"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="246"/>
        <source>Add annotation</source>
        <translation>添加注釋</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="204"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="238"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="246"/>
        <source>Highlight</source>
        <translation>高亮</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="205"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="234"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="247"/>
        <source>Search</source>
        <translation>搜索</translation>
    </message>
</context>
<context>
    <name>SideBarImageListView</name>
    <message>
        <location filename="../reader/sidebar/SideBarImageListview.cpp" line="194"/>
        <source>Copy</source>
        <translation>複製</translation>
    </message>
    <message>
        <location filename="../reader/sidebar/SideBarImageListview.cpp" line="199"/>
        <source>Remove annotation</source>
        <translation>刪除注釋</translation>
    </message>
    <message>
        <location filename="../reader/sidebar/SideBarImageListview.cpp" line="204"/>
        <location filename="../reader/sidebar/SideBarImageListview.cpp" line="223"/>
        <source>Remove all</source>
        <translation>全部刪除</translation>
    </message>
    <message>
        <location filename="../reader/sidebar/SideBarImageListview.cpp" line="218"/>
        <source>Remove bookmark</source>
        <translation>刪除書籤</translation>
    </message>
</context>
<context>
    <name>SideBarImageViewModel</name>
    <message>
        <location filename="../reader/sidebar/SideBarImageViewModel.cpp" line="135"/>
        <source>Page %1</source>
        <translation>第%1頁</translation>
    </message>
</context>
<context>
    <name>SlidePlayWidget</name>
    <message>
        <location filename="../reader/widgets/SlidePlayWidget.cpp" line="127"/>
        <source>It is the first page</source>
        <translation>已是第一頁</translation>
    </message>
    <message>
        <location filename="../reader/widgets/SlidePlayWidget.cpp" line="132"/>
        <source>It is the last page</source>
        <translation>已是最後一頁</translation>
    </message>
</context>
<context>
    <name>TitleMenu</name>
    <message>
        <location filename="../reader/uiframe/TitleMenu.cpp" line="29"/>
        <source>New window</source>
        <translation>新窗口</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/TitleMenu.cpp" line="29"/>
        <source>New tab</source>
        <translation>新標籤頁</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/TitleMenu.cpp" line="39"/>
        <location filename="../reader/uiframe/TitleMenu.cpp" line="110"/>
        <source>Save</source>
        <translation>保存</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/TitleMenu.cpp" line="39"/>
        <source>Save as</source>
        <translation>另存為</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/TitleMenu.cpp" line="44"/>
        <source>Display in file manager</source>
        <translation>在檔案管理員中顯示</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/TitleMenu.cpp" line="44"/>
        <source>Magnifer</source>
        <translation>放大鏡</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/TitleMenu.cpp" line="50"/>
        <source>Tools</source>
        <translation>工具</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/TitleMenu.cpp" line="54"/>
        <source>Search</source>
        <translation>搜索</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/TitleMenu.cpp" line="54"/>
        <source>Print</source>
        <translation>打印</translation>
    </message>
</context>
<context>
    <name>TitleWidget</name>
    <message>
        <location filename="../reader/uiframe/TitleWidget.cpp" line="37"/>
        <source>Thumbnails</source>
        <translation>縮略圖</translation>
    </message>
</context>
<context>
    <name>TransparentTextEdit</name>
    <message>
        <location filename="../reader/widgets/TransparentTextEdit.cpp" line="82"/>
        <source>Input limit reached</source>
        <translation>輸入已達上限</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../reader/main.cpp" line="40"/>
        <source>Document File Path.</source>
        <translation>Document File Path.</translation>
    </message>
    <message>
        <location filename="../reader/main.cpp" line="41"/>
        <location filename="../reader/main.cpp" line="45"/>
        <source>FilePath</source>
        <translation>FilePath</translation>
    </message>
    <message>
        <location filename="../reader/main.cpp" line="44"/>
        <source>ThumbnailPath Path.</source>
        <translation>ThumbnailPath Path.</translation>
    </message>
    <message>
        <location filename="../reader/main.cpp" line="49"/>
        <source>Generate thumbnail.</source>
        <translation>Generate thumbnail.</translation>
    </message>
</context>
</TS>